@@ -1,8 +1,10 @@
 from .reverse_proxy import ReverseProxyHandlingMiddleware
 from .session_expiration import session_expiration_middleware
+from .security_headers import SecurityHeaderMiddleware
 
 
 __all__ = (
     "ReverseProxyHandlingMiddleware",
+    "SecurityHeaderMiddleware",
     "session_expiration_middleware",
 )
